package betterquesting.questing.rewards;

import betterquesting.api.placeholders.rewards.RewardPlaceholder;
import betterquesting.api.questing.rewards.IReward;
import betterquesting.api2.storage.DBEntry;
import betterquesting.api2.storage.IDatabaseNBT;
import betterquesting.api2.storage.SimpleDatabase;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;
import javax.annotation.Nullable;
import net.minecraft.nbt.NBTBase;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import net.minecraft.util.ResourceLocation;

/* loaded from: betterquesting_questing_rewards.jar:betterquesting/questing/rewards/RewardStorage.class */
public class RewardStorage extends SimpleDatabase<IReward> implements IDatabaseNBT<IReward, NBTTagList, NBTTagList> {
    public /* bridge */ /* synthetic */ NBTBase writeToNBT(NBTBase nBTBase, @Nullable List list) {
        return writeToNBT((NBTTagList) nBTBase, (List<Integer>) list);
    }

    public /* bridge */ /* synthetic */ NBTBase writeProgressToNBT(NBTBase nBTBase, List list) {
        return writeProgressToNBT((NBTTagList) nBTBase, (List<UUID>) list);
    }

    public NBTTagList writeToNBT(NBTTagList json, @Nullable List<Integer> subset) {
        for (DBEntry<IReward> rew : getEntries()) {
            ResourceLocation rewardID = ((IReward) rew.getValue()).getFactoryID();
            NBTTagCompound rJson = ((IReward) rew.getValue()).writeToNBT(new NBTTagCompound());
            rJson.func_74778_a("rewardID", rewardID.toString());
            rJson.func_74768_a("index", rew.getID());
            json.func_74742_a(rJson);
        }
        return json;
    }

    public void readFromNBT(NBTTagList json, boolean merge) {
        if (!merge) {
            reset();
        }
        List<IReward> unassigned = new ArrayList<>();
        for (int i = 0; i < json.func_74745_c(); i++) {
            NBTTagCompound jsonReward = json.func_150305_b(i);
            ResourceLocation loc = new ResourceLocation(jsonReward.func_74779_i("rewardID"));
            int index = jsonReward.func_150297_b("index", 99) ? jsonReward.func_74762_e("index") : -1;
            IReward reward = RewardRegistry.INSTANCE.m1createNew(loc);
            if (reward instanceof RewardPlaceholder) {
                NBTTagCompound jr2 = jsonReward.func_74775_l("orig_data");
                ResourceLocation loc2 = new ResourceLocation(jr2.func_74779_i("rewardID"));
                IReward r2 = RewardRegistry.INSTANCE.m1createNew(loc2);
                if (r2 != null) {
                    jsonReward = jr2;
                    reward = r2;
                }
            }
            if (reward != null) {
                reward.readFromNBT(jsonReward);
                if (index >= 0) {
                    add(index, reward);
                } else {
                    unassigned.add(reward);
                }
            } else {
                RewardPlaceholder rph = new RewardPlaceholder();
                rph.setRewardConfigData(jsonReward);
                if (index >= 0) {
                    add(index, rph);
                } else {
                    unassigned.add(rph);
                }
            }
        }
        for (IReward r : unassigned) {
            add(nextID(), r);
        }
    }

    public NBTTagList writeProgressToNBT(NBTTagList nbt, List<UUID> users) {
        return nbt;
    }

    public void readProgressFromNBT(NBTTagList nbt, boolean merge) {
    }
}
